@@ -1,12 +1,19 @@
 from .api_common import TOOAPI_Baseclass
 from .swift_instruments import TOOAPI_Instruments
 from .swift_clock import TOOAPI_ClockCorrect
-from .api_status import Swift_TOO_Status
+from .api_status import TOOStatus
 from .api_daterange import TOOAPI_Daterange
+from .api_skycoord import TOOAPI_SkyCoord
+from .api_resolve import TOOAPI_AutoResolve
+from .swift_obsid import TOOAPI_ObsID
 
 
-class Swift_Calendar_Entry(
-    TOOAPI_Baseclass, TOOAPI_Instruments, TOOAPI_ClockCorrect, TOOAPI_Daterange
+class Swift_CalendarEntry(
+    TOOAPI_Baseclass,
+    TOOAPI_Instruments,
+    TOOAPI_ClockCorrect,
+    TOOAPI_Daterange,
+    TOOAPI_SkyCoord,
 ):
     """Class for a single entry in the Swift TOO calendar.
 
@@ -26,10 +33,18 @@ class Swift_Calendar_Entry(
         exposure time of calendar entry in seconds
     asflown: float
         estimated exposure time in seconds
+    merit: float
+        figure of merit of calendar entry
+    targetid : int
+        target ID  of the observation
+    ra : float
+        Right Ascension of pointing in J2000 (decimal degrees)
+    dec : float
+        Declination of pointing in J2000 (decimal degrees)
     """
 
     # Set up Core API values
-    _parameters = [
+    _attributes = [
         "start",
         "stop",
         "xrt_mode",
@@ -37,6 +52,10 @@ class Swift_Calendar_Entry(
         "uvot_mode",
         "duration",
         "asflown",
+        "merit",
+        "targetid",
+        "ra",
+        "dec",
     ]
     # Variable names
     _varnames = {
@@ -47,6 +66,10 @@ class Swift_Calendar_Entry(
         "uvot_mode": "UVOT Mode",
         "duration": "Exposure (s)",
         "asflown": "AFST (s)",
+        "merit": "Merit",
+        "ra": "Right Ascension (deg)",
+        "dec": "Declination (deg)",
+        "targetid": "Target ID",
     }
     api_name = "Swift_Calendar_Entry"
 
@@ -57,6 +80,8 @@ class Swift_Calendar_Entry(
         # and timedelta for relative offsets, where the start time can be
         # variable, but the monitoring cadence isn't even.
         self.stop = None
+        self.merit = None
+        self.targetid = None
         self.duration = None  # Exposure time in seconds
         self.asflown = None  # Amount of exposure taken
         self.ignorekeys = True
@@ -72,12 +97,33 @@ class Swift_Calendar_Entry(
         return header, [[getattr(self, row) for row in parameters]]
 
 
-class Swift_Calendar(TOOAPI_Baseclass, TOOAPI_ClockCorrect):
+class Swift_Calendar(
+    TOOAPI_Baseclass,
+    TOOAPI_ClockCorrect,
+    TOOAPI_Daterange,
+    TOOAPI_SkyCoord,
+    TOOAPI_AutoResolve,
+    TOOAPI_ObsID,
+):
     """Class that fetches entries in the Swift Planning Calendar, which
     are scheduled as part of a TOO request.
 
     Attributes
     ----------
+    begin : datetime
+        begin time of visibility window
+    end : datetime
+        end time of visibility window
+    length : timedelta / int
+        length of visibility window
+    ra : float
+        Right Ascension of target in J2000 (decimal degrees)
+    dec : float
+        Declination of target in J2000 (decimal degrees)
+    radius : float
+        Search radius in degrees
+    skycoord : SkyCoord
+        SkyCoord version of RA/Dec if astropy is installed
     username : str
         username for TOO API (default 'anonymous')
     shared_secret : str
@@ -85,19 +131,30 @@ class Swift_Calendar(TOOAPI_Baseclass, TOOAPI_ClockCorrect):
     too_id : int
         Unique TOO identifying number
     entries : list
-        list of calendar entries returned by query (`Swift_Calendar_Entries`)
-    status : Swift_TOO_Status
+        list of calendar entries returned by query (`Swift_CalendarEntries`)
+    status : Swift_TOOStatus
         Status of API request
     """
 
     # Core API definitions
     api_name = "Swift_Calendar"
-    _parameters = ["username", "too_id"]
+    _parameters = [
+        "username",
+        "too_id",
+        "begin",
+        "end",
+        "ra",
+        "dec",
+        "begin",
+        "end",
+        "radius",
+        "targetid",
+    ]
     _attributes = ["status", "entries"]
     # Local parameters
-    _local = ["shared_secret"]
+    _local = ["shared_secret", "length", "name"]
     # Subclasses used by class
-    _subclasses = [Swift_Calendar_Entry, Swift_TOO_Status]
+    _subclasses = [Swift_CalendarEntry, TOOStatus]
 
     def __init__(self, *args, **kwargs):
         """
@@ -114,7 +171,11 @@ class Swift_Calendar(TOOAPI_Baseclass, TOOAPI_ClockCorrect):
         self.entries = list()
         self.username = "anonymous"
         self.too_id = None
-        self.status = Swift_TOO_Status()
+        self.status = TOOStatus()
+        self.length = None
+        self.ra = None
+        self.dec = None
+        self.targetid = None
 
         # Read in arguements
         self._parseargs(*args, **kwargs)
@@ -133,7 +194,12 @@ class Swift_Calendar(TOOAPI_Baseclass, TOOAPI_ClockCorrect):
         return len(self.entries)
 
     def validate(self):
-        if self.too_id is not None:
+        if (
+            self.too_id is not None
+            or self.length is not None
+            or (self.ra is not None and self.dec is not None)
+            or self.targetid is not None
+        ):
             return True
         else:
             self.status.error("TOO ID is not set.")
@@ -154,5 +220,6 @@ class Swift_Calendar(TOOAPI_Baseclass, TOOAPI_ClockCorrect):
 
 # Shorthand alias
 Calendar = Swift_Calendar
-CalendarEntry = Swift_Calendar_Entry
-Swift_CalendarEntry = CalendarEntry
+CalendarEntry = Swift_CalendarEntry
+# Back compat
+Swift_Calendar_Entry = Swift_CalendarEntry
